@@ -1,5 +1,6 @@
-from registration.forms import RegistrationForm
 from captcha.fields import ReCaptchaField
 
+from registration.forms import RegistrationForm
+
 class RegistrationFormCaptcha(RegistrationForm):
-    captcha = ReCaptchaField()
+    captcha = ReCaptchaField(attrs={'options': {'theme': 'white'}})
